@@ -6,7 +6,7 @@ import json
 from billy import db
 from billy.importers.utils import prepare_obj
 
-PRESERVED_FIELDS = ('latest_dump_url', 'latest_dump_date',
+PRESERVED_FIELDS = ('latest_json_url', 'latest_json_date',
                     'latest_csv_url', 'latest_csv_date')
 
 
