@@ -22,7 +22,7 @@ _chamber_aliases = {
     'assembly': 'lower',
     'house': 'lower',
     'senate': 'upper',
-    }
+}
 
 
 def parse_param_dt(dt):
@@ -135,7 +135,7 @@ class MetadataHandler(BillyHandler):
         Get metadata about a legislature.
         """
         return db.metadata.find_one({'_id': abbr.lower()},
-                                   fields=_build_field_list(request))
+                                    fields=_build_field_list(request))
 
 
 class BillHandler(BillyHandler):
@@ -227,7 +227,7 @@ class LegislatorSearchHandler(BillyHandler):
         legislator_fields = _build_field_list(request, legislator_fields)
 
         _filter = _build_mongo_filter(request, ('state', 'first_name',
-                                               'last_name'))
+                                                'last_name'))
         elemMatch = _build_mongo_filter(request, ('chamber', 'term',
                                                   'district', 'party'))
         if elemMatch:
@@ -247,7 +247,7 @@ class LegislatorSearchHandler(BillyHandler):
 class CommitteeHandler(BillyHandler):
     def read(self, request, id):
         return db.committees.find_one({'_all_ids': id},
-                                     _build_field_list(request))
+                                      _build_field_list(request))
 
 
 class CommitteeSearchHandler(BillyHandler):
@@ -265,9 +265,9 @@ class StatsHandler(BillyHandler):
     def read(self, request):
         counts = {}
 
-        # db.counts contains the output of a m/r run that generates counts of
-        # bills and bill sub-objects
-        for count in db.counts.find():
+        # db.bill_stats contains the output of a m/r run that generates counts
+        # of bills and bill sub-objects
+        for count in db.bill_stats.find():
             val = count['value']
             abbr = count['_id']
 
